pub trait BootloaderSectionCallbacks: Sync {
// Required methods
fn erase(&self) -> bool;
fn write(&self, data: &[u8]);
fn finalize(&self) -> bool;
}Expand description
A trait for applications to implement to provide a bootloader section access implementation
Required Methods
Sourcefn erase(&self) -> bool
fn erase(&self) -> bool
Called to erase the section
Returns true if section is successfully erased and ready for programming
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".